import { ChtmlFontData } from 'mathjax-full/mjs/output/chtml/FontData.js';
import { CommonMathJaxDejavuFontMixin } from './common.js';
import { normal } from './chtml/normal.js';
import { bold } from './chtml/bold.js';
import { italic } from './chtml/italic.js';
import { boldItalic } from './chtml/bold-italic.js';
import { doubleStruck } from './chtml/double-struck.js';
import { fraktur } from './chtml/fraktur.js';
import { frakturBold } from './chtml/fraktur-bold.js';
import { script } from './chtml/script.js';
import { scriptBold } from './chtml/script-bold.js';
import { sansSerif } from './chtml/sans-serif.js';
import { sansSerifBold } from './chtml/sans-serif-bold.js';
import { sansSerifItalic } from './chtml/sans-serif-italic.js';
import { sansSerifBoldItalic } from './chtml/sans-serif-bold-italic.js';
import { monospace } from './chtml/monospace.js';
import { smallop } from './chtml/smallop.js';
import { largeop } from './chtml/largeop.js';
import { size3 } from './chtml/size3.js';
import { size4 } from './chtml/size4.js';
import { size5 } from './chtml/size5.js';
import { size6 } from './chtml/size6.js';
import { texCalligraphic } from './chtml/tex-calligraphic.js';
import { texCalligraphicBold } from './chtml/tex-calligraphic-bold.js';
import { texVariant } from './chtml/tex-variant.js';
import { lfTp } from './chtml/lf-tp.js';
import { rtBt } from './chtml/rt-bt.js';
import { exMd } from './chtml/ex-md.js';
import { delimiters } from './chtml/delimiters.js';
const Base = CommonMathJaxDejavuFontMixin(ChtmlFontData);
export class MathJaxDejavuFont extends Base {
    constructor() {
        super(...arguments);
        this.cssFontPrefix = 'GDV';
    }
}
MathJaxDejavuFont.NAME = 'MathJaxDejavu';
MathJaxDejavuFont.OPTIONS = Object.assign(Object.assign({}, Base.OPTIONS), { fontURL: Base.OPTIONS.dynamicPrefix = '/chtml/woff', dynamicPrefix: Base.OPTIONS.dynamicPrefix + '/chtml/dynamic' });
MathJaxDejavuFont.defaultCssFamilyPrefix = 'MJX-GDV-ZERO';
MathJaxDejavuFont.defaultVariantLetters = {
    'normal': '',
    'bold': 'B',
    'italic': 'I',
    'bold-italic': 'BI',
    'double-struck': 'DS',
    'fraktur': 'F',
    'bold-fraktur': 'FB',
    'script': 'S',
    'bold-script': 'SB',
    'sans-serif': 'SS',
    'bold-sans-serif': 'SSB',
    'sans-serif-italic': 'SSI',
    'sans-serif-bold-italic': 'SSBI',
    'monospace': 'M',
    '-smallop': 'SO',
    '-largeop': 'LO',
    '-size3': 'S3',
    '-size4': 'S4',
    '-size5': 'S5',
    '-size6': 'S6',
    '-tex-calligraphic': 'C',
    '-tex-bold-calligraphic': 'CB',
    '-tex-variant': 'V',
    '-lf-tp': 'LT',
    '-rt-bt': 'RB',
    '-ex-md': 'EM'
};
MathJaxDejavuFont.defaultDelimiters = delimiters;
MathJaxDejavuFont.defaultChars = {
    'normal': normal,
    'bold': bold,
    'italic': italic,
    'bold-italic': boldItalic,
    'double-struck': doubleStruck,
    'fraktur': fraktur,
    'bold-fraktur': frakturBold,
    'script': script,
    'bold-script': scriptBold,
    'sans-serif': sansSerif,
    'bold-sans-serif': sansSerifBold,
    'sans-serif-italic': sansSerifItalic,
    'sans-serif-bold-italic': sansSerifBoldItalic,
    'monospace': monospace,
    '-smallop': smallop,
    '-largeop': largeop,
    '-size3': size3,
    '-size4': size4,
    '-size5': size5,
    '-size6': size6,
    '-tex-calligraphic': texCalligraphic,
    '-tex-bold-calligraphic': texCalligraphicBold,
    '-tex-variant': texVariant,
    '-lf-tp': lfTp,
    '-rt-bt': rtBt,
    '-ex-md': exMd
};
MathJaxDejavuFont.defaultStyles = Object.assign(Object.assign({}, ChtmlFontData.defaultStyles), { '.GDV-N': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-N'
    }, '.GDV-B': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-B'
    }, '.GDV-I': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-I'
    }, '.GDV-BI': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-BI'
    }, '.GDV-DS': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-DS'
    }, '.GDV-F': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-F'
    }, '.GDV-FB': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-FB'
    }, '.GDV-S': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-S'
    }, '.GDV-SB': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-SB'
    }, '.GDV-SS': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-SS'
    }, '.GDV-SSB': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-SSB'
    }, '.GDV-SSI': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-SSI'
    }, '.GDV-SSBI': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-SSBI'
    }, '.GDV-M': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-M'
    }, '.GDV-SO': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-SO'
    }, '.GDV-LO': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-LO'
    }, '.GDV-S3': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-S3'
    }, '.GDV-S4': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-S4'
    }, '.GDV-S5': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-S5'
    }, '.GDV-S6': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-S6'
    }, '.GDV-C': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-C'
    }, '.GDV-CB': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-CB'
    }, '.GDV-V': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-V'
    }, '.GDV-LT': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-LT'
    }, '.GDV-RB': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-RB'
    }, '.GDV-EM': {
        'font-family': 'MJX-GDV-ZERO, MJX-GDV-EM'
    } });
MathJaxDejavuFont.defaultFonts = Object.assign(Object.assign({}, ChtmlFontData.defaultFonts), { '@font-face /* MJX-GDV-ZERO */': {
        'font-family': 'MJX-GDV-ZERO',
        src: 'url("%%URL%%/mjx-gdv-zero.woff") format("woff")'
    }, '@font-face /* MJX-BRK */': {
        'font-family': 'MJX-BRK',
        src: 'url("%%URL%%/mjx-gdv-brk.woff") format("woff")'
    }, '@font-face /* MJX-GDV-N */': {
        'font-family': 'MJX-GDV-N',
        src: 'url("%%URL%%/mjx-gdv-n.woff") format("woff")'
    }, '@font-face /* MJX-GDV-B */': {
        'font-family': 'MJX-GDV-B',
        src: 'url("%%URL%%/mjx-gdv-b.woff") format("woff")'
    }, '@font-face /* MJX-GDV-I */': {
        'font-family': 'MJX-GDV-I',
        src: 'url("%%URL%%/mjx-gdv-i.woff") format("woff")'
    }, '@font-face /* MJX-GDV-BI */': {
        'font-family': 'MJX-GDV-BI',
        src: 'url("%%URL%%/mjx-gdv-bi.woff") format("woff")'
    }, '@font-face /* MJX-GDV-DS */': {
        'font-family': 'MJX-GDV-DS',
        src: 'url("%%URL%%/mjx-gdv-ds.woff") format("woff")'
    }, '@font-face /* MJX-GDV-F */': {
        'font-family': 'MJX-GDV-F',
        src: 'url("%%URL%%/mjx-gdv-f.woff") format("woff")'
    }, '@font-face /* MJX-GDV-FB */': {
        'font-family': 'MJX-GDV-FB',
        src: 'url("%%URL%%/mjx-gdv-fb.woff") format("woff")'
    }, '@font-face /* MJX-GDV-S */': {
        'font-family': 'MJX-GDV-S',
        src: 'url("%%URL%%/mjx-gdv-s.woff") format("woff")'
    }, '@font-face /* MJX-GDV-SB */': {
        'font-family': 'MJX-GDV-SB',
        src: 'url("%%URL%%/mjx-gdv-sb.woff") format("woff")'
    }, '@font-face /* MJX-GDV-SS */': {
        'font-family': 'MJX-GDV-SS',
        src: 'url("%%URL%%/mjx-gdv-ss.woff") format("woff")'
    }, '@font-face /* MJX-GDV-SSB */': {
        'font-family': 'MJX-GDV-SSB',
        src: 'url("%%URL%%/mjx-gdv-ssb.woff") format("woff")'
    }, '@font-face /* MJX-GDV-SSI */': {
        'font-family': 'MJX-GDV-SSI',
        src: 'url("%%URL%%/mjx-gdv-ssi.woff") format("woff")'
    }, '@font-face /* MJX-GDV-SSBI */': {
        'font-family': 'MJX-GDV-SSBI',
        src: 'url("%%URL%%/mjx-gdv-ssbi.woff") format("woff")'
    }, '@font-face /* MJX-GDV-M */': {
        'font-family': 'MJX-GDV-M',
        src: 'url("%%URL%%/mjx-gdv-m.woff") format("woff")'
    }, '@font-face /* MJX-GDV-SO */': {
        'font-family': 'MJX-GDV-SO',
        src: 'url("%%URL%%/mjx-gdv-so.woff") format("woff")'
    }, '@font-face /* MJX-GDV-LO */': {
        'font-family': 'MJX-GDV-LO',
        src: 'url("%%URL%%/mjx-gdv-lo.woff") format("woff")'
    }, '@font-face /* MJX-GDV-S3 */': {
        'font-family': 'MJX-GDV-S3',
        src: 'url("%%URL%%/mjx-gdv-s3.woff") format("woff")'
    }, '@font-face /* MJX-GDV-S4 */': {
        'font-family': 'MJX-GDV-S4',
        src: 'url("%%URL%%/mjx-gdv-s4.woff") format("woff")'
    }, '@font-face /* MJX-GDV-S5 */': {
        'font-family': 'MJX-GDV-S5',
        src: 'url("%%URL%%/mjx-gdv-s5.woff") format("woff")'
    }, '@font-face /* MJX-GDV-S6 */': {
        'font-family': 'MJX-GDV-S6',
        src: 'url("%%URL%%/mjx-gdv-s6.woff") format("woff")'
    }, '@font-face /* MJX-GDV-C */': {
        'font-family': 'MJX-GDV-C',
        src: 'url("%%URL%%/mjx-gdv-c.woff") format("woff")'
    }, '@font-face /* MJX-GDV-CB */': {
        'font-family': 'MJX-GDV-CB',
        src: 'url("%%URL%%/mjx-gdv-cb.woff") format("woff")'
    }, '@font-face /* MJX-GDV-V */': {
        'font-family': 'MJX-GDV-V',
        src: 'url("%%URL%%/mjx-gdv-v.woff") format("woff")'
    }, '@font-face /* MJX-GDV-LT */': {
        'font-family': 'MJX-GDV-LT',
        src: 'url("%%URL%%/mjx-gdv-lt.woff") format("woff")'
    }, '@font-face /* MJX-GDV-RB */': {
        'font-family': 'MJX-GDV-RB',
        src: 'url("%%URL%%/mjx-gdv-rb.woff") format("woff")'
    }, '@font-face /* MJX-GDV-EM */': {
        'font-family': 'MJX-GDV-EM',
        src: 'url("%%URL%%/mjx-gdv-em.woff") format("woff")'
    } });
MathJaxDejavuFont.dynamicFiles = ChtmlFontData.defineDynamicFiles([
    ['latin', {
            'normal': [
                [0xC0, 0xD6], [0xD8, 0xEF], [0xF1, 0xF6], [0xF8, 0x107], [0x10C, 0x113], [0x116, 0x11B], 0x11E, 0x11F, 0x122, 0x123, [0x128, 0x12B], [0x12E, 0x130], 0x132, 0x133, 0x136, 0x137, [0x139, 0x13E], [0x141, 0x148], [0x14A, 0x14D], [0x150, 0x15B], [0x15E, 0x165], [0x168, 0x16B], [0x16E, 0x173], [0x178, 0x17F], 0x192, 0x1A0, 0x1A1, 0x1AF, 0x1B0, [0x1EA, 0x1ED], [0x218, 0x21B], 0x1E9E, [0x1EA0, 0x1EF9]
            ]
        }],
    ['latin-b', {
            'bold': []
        }],
    ['latin-i', {
            'italic': []
        }],
    ['latin-bi', {
            'bold-italic': []
        }],
    ['double-struck', {
            'normal': [
                0x2102, 0x210D, 0x2115, 0x2119, 0x211A, 0x211D, 0x2124, [0x213C, 0x2140], [0x2145, 0x2149], 0x1D538, 0x1D539, [0x1D53B, 0x1D53E], [0x1D540, 0x1D544], 0x1D546, [0x1D54A, 0x1D550], [0x1D552, 0x1D56B], [0x1D7D8, 0x1D7E1]
            ],
            'double-struck': [
                0x131, 0x237
            ]
        }, [0x2140]],
    ['fraktur', {
            'normal': [
                0x210C, 0x2111, 0x211C, 0x2128, 0x212D, 0x1D504, 0x1D505, [0x1D507, 0x1D50A], [0x1D50D, 0x1D514], [0x1D516, 0x1D51C], [0x1D51E, 0x1D537], [0x1D56C, 0x1D59F]
            ],
            'fraktur': [
                0x131, 0x237
            ],
            'bold-fraktur': [
                0x131, 0x237
            ]
        }],
    ['script', {
            'normal': [
                0x210A, 0x210B, 0x2110, 0x2112, 0x2113, 0x2118, 0x211B, 0x212C, [0x212F, 0x2131], 0x2133, 0x2134, 0x1D49C, 0x1D49E, 0x1D49F, 0x1D4A2, 0x1D4A5, 0x1D4A6, [0x1D4A9, 0x1D4AC], [0x1D4AE, 0x1D4B9], 0x1D4BB, [0x1D4BD, 0x1D4C3], [0x1D4C5, 0x1D503]
            ],
            'script': [
                0x131, 0x237
            ],
            'bold-script': [
                0x131, 0x237
            ]
        }],
    ['sans-serif', {
            'normal': [
                [0x1D5A0, 0x1D66F], [0x1D7E2, 0x1D7F5]
            ],
            'sans-serif': [
                0x131, 0x237
            ],
            'bold-sans-serif': [
                0x131, 0x237
            ],
            'sans-serif-italic': [
                0x131, 0x237
            ],
            'sans-serif-bold-italic': [
                0x131, 0x237
            ]
        }],
    ['monospace', {
            'normal': [
                [0x1D670, 0x1D6A3], [0x1D7F6, 0x1D7FF]
            ],
            'monospace': [
                0x131, 0x237
            ]
        }],
    ['calligraphic', {
            '-tex-calligraphic': [
                [0x41, 0x5A], [0x61, 0x7A], 0x131, 0x237
            ],
            '-tex-bold-calligraphic': [
                [0x41, 0x5A], [0x61, 0x7A], 0x131, 0x237
            ]
        }],
    ['symbols', {
            'normal': [
                0xA1, 0xA2, 0xA4, 0xA6, [0xA9, 0xAB], 0xAE, 0xBA, 0xBB, 0xBF, 0xE3F, 0x200C, 0x200D, 0x2017, 0x201A, 0x201E, 0x2022, 0x2030, 0x2031, [0x2039, 0x203B], 0x203D, 0x2052, 0x20A1, 0x20A6, 0x20A9, 0x20AB, 0x20B1, 0x20B2, 0x2103, 0x2109, 0x2116, 0x2117, 0x211E, 0x2120, 0x2122, 0x212E, 0x2300, 0x2305, 0x2306, 0x2422, 0x2423, 0x2E18, 0x3016, 0x3017, [0xFB00, 0xFB04], 0xFEFF
            ],
            '-largeop': [
                0x2140
            ]
        }, [0x2017]],
    ['symbols-b-i', {
            'bold': [],
            'italic': [],
            'bold-italic': []
        }],
    ['arrows', {
            'normal': [
                0x219F, 0x21A1, 0x21A5, 0x21A7, 0x21AD, [0x21B0, 0x21B5], [0x21D6, 0x21D9], 0x21DC, 0x21DD, [0x21E6, 0x21E9], 0x21F3, 0x27A1, 0x27F4, 0x27FF, 0x2906, 0x2907, 0x294C, 0x294D, 0x294F, 0x2951, 0x295C, 0x295D, 0x2960, 0x2961, [0x2B04, 0x2B07], 0x2B0C, 0x2B0D, 0x2B31, 0x2B33
            ],
            'bold': [],
            '-largeop': [
                0x2191, 0x2193, [0x2195, 0x219B], [0x219E, 0x21A3], 0x21A5, 0x21A7, [0x21A9, 0x21AE], [0x21B0, 0x21B3], 0x21B6, 0x21B7, [0x21BC, 0x21CF], 0x21D1, 0x21D3, [0x21D5, 0x21DB], [0x21E6, 0x21E9], 0x21F3, 0x21F5, 0x21F6, [0x2B04, 0x2B07], 0x2B0C, 0x2B0D, 0x2B31
            ],
            '-lf-tp': [
                [0x21E6, 0x21E9], 0x2907, 0x2B05, 0x2B06
            ],
            '-rt-bt': [
                [0x21E6, 0x21E9], 0x2906, 0x2B07, 0x2B0C
            ],
            '-ex-md': [
                0x21E6, 0x21E7, 0x2B05, 0x2B06
            ]
        }, [0x219F, [0x2196, 0x2199], 0x21A1, 0x21A5, 0x21A7, 0x21AD, [0x21B0, 0x21B3], 0x21B6, 0x21B7, [0x21D6, 0x21D9], 0x21DC, 0x21DD, [0x21E6, 0x21E9], 0x21F3, 0x27A1, 0x27FD, 0x27FE, 0x2906, 0x2907, 0x294C, 0x294D, 0x294F, 0x2951, 0x295C, 0x295D, 0x2960, 0x2961, [0x2B04, 0x2B07], 0x2B0C, 0x2B0D, 0x2B31]],
    ['accents', {
            'normal': [
                0xB8, 0x2DB, 0x2DD, 0x309, 0x30B, 0x30F, 0x311, 0x323, 0x326, [0x32C, 0x333], 0x33F, 0x34D, [0x20D3, 0x20D5], 0x20D8, [0x20DD, 0x20DF], [0x20E4, 0x20E6], [0x20E8, 0x20EB], 0x20F0
            ],
            '-smallop': [
                0x311, [0x32C, 0x330], 0x332, 0x333, 0x33F, 0x34D
            ],
            '-largeop': [
                0x311, [0x32C, 0x330]
            ],
            '-size3': [
                0x311, [0x32C, 0x330]
            ],
            '-size4': [
                0x311, [0x32C, 0x330]
            ],
            '-size5': [
                0x311, [0x32C, 0x330]
            ],
            '-size6': [
                0x311, [0x32C, 0x330]
            ],
            '-ex-md': [
                0x332, 0x333, 0x33F, 0x34D
            ]
        }, [0x311, [0x32C, 0x330], 0x332, 0x333, 0x33F, 0x34D, 0x20E9]],
    ['accents-b-i', {
            'bold': [],
            'italic': [],
            'bold-italic': []
        }],
    ['shapes', {
            'normal': [
                0x2500, 0x2502, 0x250C, 0x2510, 0x2514, 0x2518, 0x251C, 0x2524, 0x252C, 0x2534, 0x253C, 0x2581, 0x2588, [0x2591, 0x2593], 0x25AC, 0x25AD, [0x2660, 0x2667], 0x266A, [0x266D, 0x266F], 0x26AD, 0x26AE, 0x2713, 0x2720, 0x27A1, 0x2B1A
            ],
            'bold': [],
            'italic': [],
            'bold-italic': []
        }],
    ['stretchy', {
            'normal': [
                0x2320, 0x2321, 0x23B2, 0x23B3
            ],
            'bold': [],
            '-size3': [
                [0x222B, 0x2233], 0x2A0C, 0x2A11
            ],
            '-size4': [
                [0x222B, 0x2233], 0x2A0C, 0x2A11
            ],
            '-size5': [
                [0x222B, 0x2233], 0x2A0C, 0x2A11
            ],
            '-size6': [
                [0x222B, 0x2233], 0x2A0C, 0x2A11
            ],
            '-lf-tp': [
                [0x222B, 0x222D], 0x2A0C
            ],
            '-rt-bt': [
                [0x222B, 0x222D], 0x2A0C
            ],
            '-ex-md': [
                0x222C, 0x222D, 0x2A0C
            ]
        }, [[0x222B, 0x2233], 0x2A0C, 0x2A11, 0x2140, [0x22A2, 0x22A5], [0x22C0, 0x22C3], [0x2A00, 0x2A06], 0x2A09]],
    ['variants', {
            '-tex-variant': [
                0x22, 0x27, 0x2A, 0x60, 0x7E, 0xAA, 0xB0, 0xB2, 0xB3, 0xB9, 0xBA, 0x2014, 0x2061, 0x2070, 0x2071, [0x2074, 0x208E]
            ]
        }],
    ['PUA', {
            'normal': [
                0xE803, 0xEA1F, 0xEA26, 0xEA35, 0xEA3E, 0xEB0F, 0xEB16, 0xEB19, 0xEB40, 0xEB4D, 0xEC10, 0xEC11, 0xF6DE
            ],
            'bold': [],
            'italic': [],
            'bold-italic': []
        }]
]);
//# sourceMappingURL=chtml.js.map