import { SvgFontData } from 'mathjax-full/mjs/output/svg/FontData.js';
import { CommonMathJaxDejavuFontMixin } from './common.js';
import { normal } from './svg/normal.js';
import { bold } from './svg/bold.js';
import { italic } from './svg/italic.js';
import { boldItalic } from './svg/bold-italic.js';
import { doubleStruck } from './svg/double-struck.js';
import { fraktur } from './svg/fraktur.js';
import { frakturBold } from './svg/fraktur-bold.js';
import { script } from './svg/script.js';
import { scriptBold } from './svg/script-bold.js';
import { sansSerif } from './svg/sans-serif.js';
import { sansSerifBold } from './svg/sans-serif-bold.js';
import { sansSerifItalic } from './svg/sans-serif-italic.js';
import { sansSerifBoldItalic } from './svg/sans-serif-bold-italic.js';
import { monospace } from './svg/monospace.js';
import { smallop } from './svg/smallop.js';
import { largeop } from './svg/largeop.js';
import { size3 } from './svg/size3.js';
import { size4 } from './svg/size4.js';
import { size5 } from './svg/size5.js';
import { size6 } from './svg/size6.js';
import { texCalligraphic } from './svg/tex-calligraphic.js';
import { texCalligraphicBold } from './svg/tex-calligraphic-bold.js';
import { texVariant } from './svg/tex-variant.js';
import { lfTp } from './svg/lf-tp.js';
import { rtBt } from './svg/rt-bt.js';
import { exMd } from './svg/ex-md.js';
import { delimiters } from './svg/delimiters.js';
const Base = CommonMathJaxDejavuFontMixin(SvgFontData);
export class MathJaxDejavuFont extends Base {
    constructor(options = {}) {
        super(options);
        const CLASS = this.constructor;
        for (const variant of Object.keys(CLASS.variantCacheIds)) {
            this.variant[variant].cacheID = 'GDV-' + CLASS.variantCacheIds[variant];
        }
    }
}
MathJaxDejavuFont.NAME = 'MathJaxDejavu';
MathJaxDejavuFont.OPTIONS = Object.assign(Object.assign({}, Base.OPTIONS), { dynamicPrefix: Base.OPTIONS.dynamicPrefix + '/svg/dynamic' });
MathJaxDejavuFont.defaultDelimiters = delimiters;
MathJaxDejavuFont.defaultChars = {
    'normal': normal,
    'bold': bold,
    'italic': italic,
    'bold-italic': boldItalic,
    'double-struck': doubleStruck,
    'fraktur': fraktur,
    'bold-fraktur': frakturBold,
    'script': script,
    'bold-script': scriptBold,
    'sans-serif': sansSerif,
    'bold-sans-serif': sansSerifBold,
    'sans-serif-italic': sansSerifItalic,
    'sans-serif-bold-italic': sansSerifBoldItalic,
    'monospace': monospace,
    '-smallop': smallop,
    '-largeop': largeop,
    '-size3': size3,
    '-size4': size4,
    '-size5': size5,
    '-size6': size6,
    '-tex-calligraphic': texCalligraphic,
    '-tex-bold-calligraphic': texCalligraphicBold,
    '-tex-variant': texVariant,
    '-lf-tp': lfTp,
    '-rt-bt': rtBt,
    '-ex-md': exMd
};
MathJaxDejavuFont.dynamicFiles = SvgFontData.defineDynamicFiles([
    ['latin', {
            'normal': [
                [0xC0, 0xD6], [0xD8, 0xEF], [0xF1, 0xF6], [0xF8, 0x107], [0x10C, 0x113], [0x116, 0x11B], 0x11E, 0x11F, 0x122, 0x123, [0x128, 0x12B], [0x12E, 0x130], 0x132, 0x133, 0x136, 0x137, [0x139, 0x13E], [0x141, 0x148], [0x14A, 0x14D], [0x150, 0x15B], [0x15E, 0x165], [0x168, 0x16B], [0x16E, 0x173], [0x178, 0x17F], 0x192, 0x1A0, 0x1A1, 0x1AF, 0x1B0, [0x1EA, 0x1ED], [0x218, 0x21B], 0x1E9E, [0x1EA0, 0x1EF9]
            ]
        }],
    ['latin-b', {
            'bold': []
        }],
    ['latin-i', {
            'italic': []
        }],
    ['latin-bi', {
            'bold-italic': []
        }],
    ['double-struck', {
            'normal': [
                0x1D538, 0x1D539, [0x1D53B, 0x1D53E], [0x1D540, 0x1D544], 0x1D546, [0x1D54A, 0x1D550], [0x1D552, 0x1D56B], [0x1D7D8, 0x1D7E1], 0x2102, 0x210D, 0x2115, 0x2119, 0x211A, 0x211D, 0x2124, [0x213C, 0x2140], [0x2145, 0x2149]
            ],
            'double-struck': [
                0x131, 0x237
            ]
        }, [0x2140]],
    ['fraktur', {
            'normal': [
                0x1D504, 0x1D505, [0x1D507, 0x1D50A], [0x1D50D, 0x1D514], [0x1D516, 0x1D51C], [0x1D51E, 0x1D537], [0x1D56C, 0x1D59F], 0x210C, 0x2111, 0x211C, 0x2128, 0x212D
            ],
            'fraktur': [
                0x131, 0x237
            ],
            'bold-fraktur': [
                0x131, 0x237
            ]
        }],
    ['script', {
            'normal': [
                0x1D49C, 0x1D49E, 0x1D49F, 0x1D4A2, 0x1D4A5, 0x1D4A6, [0x1D4A9, 0x1D4AC], [0x1D4AE, 0x1D4B9], 0x1D4BB, [0x1D4BD, 0x1D4C3], [0x1D4C5, 0x1D503], 0x210A, 0x210B, 0x2110, 0x2112, 0x2113, 0x2118, 0x211B, 0x212C, [0x212F, 0x2131], 0x2133, 0x2134
            ],
            'script': [
                0x131, 0x237
            ],
            'bold-script': [
                0x131, 0x237
            ]
        }],
    ['sans-serif', {
            'normal': [
                [0x1D5A0, 0x1D66F], [0x1D7E2, 0x1D7F5]
            ],
            'sans-serif': [
                0x131, 0x237
            ],
            'bold-sans-serif': [
                0x131, 0x237
            ],
            'sans-serif-italic': [
                0x131, 0x237
            ],
            'sans-serif-bold-italic': [
                0x131, 0x237
            ]
        }],
    ['monospace', {
            'normal': [
                [0x1D670, 0x1D6A3], [0x1D7F6, 0x1D7FF]
            ],
            'monospace': [
                0x131, 0x237
            ]
        }],
    ['calligraphic', {
            '-tex-calligraphic': [
                [0x64, 0x7A], 0x131, 0x237, [0x41, 0x5A], [0x61, 0x63]
            ],
            '-tex-bold-calligraphic': [
                [0x64, 0x7A], 0x131, 0x237, [0x41, 0x5A], [0x61, 0x63]
            ]
        }],
    ['symbols', {
            'normal': [
                0x2E18, 0x3016, 0x3017, 0xA1, 0xA2, 0xA4, 0xA6, [0xA9, 0xAB], 0xAE, 0xBA, 0xBB, 0xBF, 0xE3F, [0xFB00, 0xFB04], 0xFEFF, 0x200C, 0x200D, 0x2017, 0x201A, 0x201E, 0x2022, 0x2030, 0x2031, [0x2039, 0x203B], 0x203D, 0x2052, 0x20A1, 0x20A6, 0x20A9, 0x20AB, 0x20B1, 0x20B2, 0x2103, 0x2109, 0x2116, 0x2117, 0x211E, 0x2120, 0x2122, 0x212E, 0x2300, 0x2305, 0x2306, 0x2422, 0x2423
            ],
            '-largeop': [
                0x2140
            ]
        }, [0x2017]],
    ['symbols-b-i', {
            'bold': [],
            'italic': [],
            'bold-italic': []
        }],
    ['arrows', {
            'normal': [
                0x27A1, 0x27F4, 0x27FF, 0x2906, 0x2907, 0x294C, 0x294D, 0x294F, 0x2951, 0x295C, 0x295D, 0x2960, 0x2961, [0x2B04, 0x2B07], 0x2B0C, 0x2B0D, 0x2B31, 0x2B33, 0x219F, 0x21A1, 0x21A5, 0x21A7, 0x21AD, [0x21B0, 0x21B5], [0x21D6, 0x21D9], 0x21DC, 0x21DD, [0x21E6, 0x21E9], 0x21F3
            ],
            'bold': [],
            '-largeop': [
                [0x2B04, 0x2B07], 0x2B0C, 0x2B0D, 0x2B31, 0x2191, 0x2193, [0x2195, 0x219B], [0x219E, 0x21A3], 0x21A5, 0x21A7, [0x21A9, 0x21AE], [0x21B0, 0x21B3], 0x21B6, 0x21B7, [0x21BC, 0x21CF], 0x21D1, 0x21D3, [0x21D5, 0x21DB], [0x21E6, 0x21E9], 0x21F3, 0x21F5, 0x21F6
            ],
            '-lf-tp': [
                0x2907, 0x2B05, 0x2B06, [0x21E6, 0x21E9]
            ],
            '-rt-bt': [
                0x2906, 0x2B07, 0x2B0C, [0x21E6, 0x21E9]
            ],
            '-ex-md': [
                0x2B05, 0x2B06, 0x21E6, 0x21E7
            ]
        }, [0x219F, [0x2196, 0x2199], 0x21A1, 0x21A5, 0x21A7, 0x21AD, [0x21B0, 0x21B3], 0x21B6, 0x21B7, [0x21D6, 0x21D9], 0x21DC, 0x21DD, [0x21E6, 0x21E9], 0x21F3, 0x27A1, 0x27FD, 0x27FE, 0x2906, 0x2907, 0x294C, 0x294D, 0x294F, 0x2951, 0x295C, 0x295D, 0x2960, 0x2961, [0x2B04, 0x2B07], 0x2B0C, 0x2B0D, 0x2B31]],
    ['accents', {
            'normal': [
                0xB8, 0x2DB, 0x2DD, 0x309, 0x30B, 0x30F, 0x311, 0x323, 0x326, [0x32C, 0x333], 0x33F, [0x20D3, 0x20D5], 0x20D8, [0x20DD, 0x20DF], [0x20E4, 0x20E6], [0x20E8, 0x20EB], 0x20F0, 0x34D
            ],
            '-smallop': [
                0x311, [0x32C, 0x330], 0x332, 0x333, 0x33F, 0x34D
            ],
            '-largeop': [
                0x311, [0x32C, 0x330]
            ],
            '-size3': [
                0x311, [0x32C, 0x330]
            ],
            '-size4': [
                0x311, [0x32C, 0x330]
            ],
            '-size5': [
                0x311, [0x32C, 0x330]
            ],
            '-size6': [
                0x311, [0x32C, 0x330]
            ],
            '-ex-md': [
                0x332, 0x333, 0x33F, 0x34D
            ]
        }, [0x311, [0x32C, 0x330], 0x332, 0x333, 0x33F, 0x34D, 0x20E9]],
    ['accents-b-i', {
            'bold': [],
            'italic': [],
            'bold-italic': []
        }],
    ['shapes', {
            'normal': [
                0x2713, 0x2720, 0x27A1, 0x2B1A, 0x2500, 0x2502, 0x250C, 0x2510, 0x2514, 0x2518, 0x251C, 0x2524, 0x252C, 0x2534, 0x253C, 0x2581, 0x2588, [0x2591, 0x2593], 0x25AC, 0x25AD, [0x2660, 0x2667], 0x266A, [0x266D, 0x266F], 0x26AD, 0x26AE
            ],
            'bold': [],
            'italic': [],
            'bold-italic': []
        }],
    ['stretchy', {
            'normal': [
                0x2320, 0x2321, 0x23B2, 0x23B3
            ],
            'bold': [],
            '-size3': [
                0x2A0C, 0x2A11, [0x222B, 0x2233]
            ],
            '-size4': [
                0x2A0C, 0x2A11, [0x222B, 0x2233]
            ],
            '-size5': [
                0x2A0C, 0x2A11, [0x222B, 0x2233]
            ],
            '-size6': [
                0x2A0C, 0x2A11, [0x222B, 0x2233]
            ],
            '-lf-tp': [
                0x2A0C, [0x222B, 0x222D]
            ],
            '-rt-bt': [
                0x2A0C, [0x222B, 0x222D]
            ],
            '-ex-md': [
                0x2A0C, 0x222C, 0x222D
            ]
        }, [[0x222B, 0x2233], 0x2A0C, 0x2A11, 0x2140, [0x22A2, 0x22A5], [0x22C0, 0x22C3], [0x2A00, 0x2A06], 0x2A09]],
    ['variants', {
            '-tex-variant': [
                0x7E, 0xAA, 0xB0, 0xB2, 0xB3, 0xB9, 0xBA, 0x22, 0x27, 0x2A, 0x2014, 0x2061, 0x2070, 0x2071, [0x2074, 0x208E], 0x60
            ]
        }],
    ['PUA', {
            'normal': [
                0xE803, 0xEA1F, 0xEA26, 0xEA35, 0xEA3E, 0xEB0F, 0xEB16, 0xEB19, 0xEB40, 0xEB4D, 0xEC10, 0xEC11, 0xF6DE
            ],
            'bold': [],
            'italic': [],
            'bold-italic': []
        }]
]);
MathJaxDejavuFont.variantCacheIds = {
    'normal': 'N',
    'bold': 'B',
    'italic': 'I',
    'bold-italic': 'BI',
    'double-struck': 'DS',
    'fraktur': 'F',
    'bold-fraktur': 'FB',
    'script': 'S',
    'bold-script': 'SB',
    'sans-serif': 'SS',
    'bold-sans-serif': 'SSB',
    'sans-serif-italic': 'SSI',
    'sans-serif-bold-italic': 'SSBI',
    'monospace': 'M',
    '-smallop': 'SO',
    '-largeop': 'LO',
    '-size3': 'S3',
    '-size4': 'S4',
    '-size5': 'S5',
    '-size6': 'S6',
    '-tex-calligraphic': 'C',
    '-tex-bold-calligraphic': 'CB',
    '-tex-variant': 'V',
    '-lf-tp': 'LT',
    '-rt-bt': 'RB',
    '-ex-md': 'EM'
};
//# sourceMappingURL=svg.js.map